# Ambit-Stochastics
A repository dedicated to the study of Ambit fields and Trawl processes. The library can be downloaded from https://pypi.org/project/Ambit-Stochastics/.

The `Trawl processes example usage` and `Simple ambit field example usage` jupyter notebooks in the git root folder explains the functionality of the library. The full documentation is available at https://danleonte.github.io/Ambit_Stochastics/index.html

